==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/RouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.RouteArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.RouteNextHopType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Route resource.
 * @property addressPrefix The destination CIDR to which the route applies.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property hasBgpOverride A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property nextHopIpAddress The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
 * @property nextHopType The type of Azure hop the packet should be sent to.
 * @property provisioningState The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
 * @property type The type of the resource.
 */
public data class RouteArgs(
    public val addressPrefix: Output<String>? = null,
    public val etag: Output<String>? = null,
    public val hasBgpOverride: Output<Boolean>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val nextHopIpAddress: Output<String>? = null,
    public val nextHopType: Output<Either<String, RouteNextHopType>>,
    public val provisioningState: Output<String>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.RouteArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.RouteArgs =
        com.pulumi.azurenative.network.inputs.RouteArgs.builder()
            .addressPrefix(addressPrefix?.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .hasBgpOverride(hasBgpOverride?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .nextHopIpAddress(nextHopIpAddress?.applyValue({ args0 -> args0 }))
            .nextHopType(
                nextHopType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteArgs].
 */
@PulumiTagMarker
public class RouteArgsBuilder internal constructor() {
    private var addressPrefix: Output<String>? = null

    private var etag: Output<String>? = null

    private var hasBgpOverride: Output<Boolean>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var nextHopIpAddress: Output<String>? = null

    private var nextHopType: Output<Either<String, RouteNextHopType>>? = null

    private var provisioningState: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The destination CIDR to which the route applies.
     */
    @JvmName("inyfqwqnnqprddio")
    public suspend fun addressPrefix(`value`: Output<String>) {
        this.addressPrefix = value
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("sqysbqxurtbdtfbx")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
     */
    @JvmName("symbtmamgammplna")
    public suspend fun hasBgpOverride(`value`: Output<Boolean>) {
        this.hasBgpOverride = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("vhpnpkxexmxeggoy")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("pjkekwtpcvbkuqur")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
     */
    @JvmName("uhdmqnjlwqfwhiux")
    public suspend fun nextHopIpAddress(`value`: Output<String>) {
        this.nextHopIpAddress = value
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("glgepnrspwbfmtop")
    public suspend fun nextHopType(`value`: Output<Either<String, RouteNextHopType>>) {
        this.nextHopType = value
    }

    /**
     * @param value The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
     */
    @JvmName("takyvpyrbxtaashl")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value The type of the resource.
     */
    @JvmName("rxvxvphyaooxepkx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The destination CIDR to which the route applies.
     */
    @JvmName("wwtjuicnbygadgnb")
    public suspend fun addressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefix = mapped
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("umxtfrwrlqmfkeij")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
     */
    @JvmName("laelxyquibnpurse")
    public suspend fun hasBgpOverride(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hasBgpOverride = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("fgoqftbkymdmipxy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("xfqbwkdfcybgkuaw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
     */
    @JvmName("sjkhyqyaoruktfbr")
    public suspend fun nextHopIpAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nextHopIpAddress = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("dhxavtuwdrhepssa")
    public suspend fun nextHopType(`value`: Either<String, RouteNextHopType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("wqebvqkjjjrbdrvs")
    public fun nextHopType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RouteNextHopType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("fkkhwpdxaxdfxoim")
    public fun nextHopType(`value`: RouteNextHopType) {
        val toBeMapped = Either.ofRight<String, RouteNextHopType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
     */
    @JvmName("ltbgrdggniknjqoa")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The type of the resource.
     */
    @JvmName("ukwnknhvuhgpcpme")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): RouteArgs = RouteArgs(
        addressPrefix = addressPrefix,
        etag = etag,
        hasBgpOverride = hasBgpOverride,
        id = id,
        name = name,
        nextHopIpAddress = nextHopIpAddress,
        nextHopType = nextHopType ?: throw PulumiNullFieldException("nextHopType"),
        provisioningState = provisioningState,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/RouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.RouteArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.RouteNextHopType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Route resource.
 * @property addressPrefix The destination CIDR to which the route applies.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property hasBgpOverride A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property nextHopIpAddress The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
 * @property nextHopType The type of Azure hop the packet should be sent to.
 * @property provisioningState The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
 * @property type The type of the resource.
 */
public data class RouteArgs(
    public val addressPrefix: Output<String>? = null,
    public val etag: Output<String>? = null,
    public val hasBgpOverride: Output<Boolean>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val nextHopIpAddress: Output<String>? = null,
    public val nextHopType: Output<Either<String, RouteNextHopType>>,
    public val provisioningState: Output<String>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.RouteArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.RouteArgs =
        com.pulumi.azurenative.network.inputs.RouteArgs.builder()
            .addressPrefix(addressPrefix?.applyValue({ args0 -> args0 }))
            .etag(etag?.applyValue({ args0 -> args0 }))
            .hasBgpOverride(hasBgpOverride?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .nextHopIpAddress(nextHopIpAddress?.applyValue({ args0 -> args0 }))
            .nextHopType(
                nextHopType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .provisioningState(provisioningState?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RouteArgs].
 */
@PulumiTagMarker
public class RouteArgsBuilder internal constructor() {
    private var addressPrefix: Output<String>? = null

    private var etag: Output<String>? = null

    private var hasBgpOverride: Output<Boolean>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var nextHopIpAddress: Output<String>? = null

    private var nextHopType: Output<Either<String, RouteNextHopType>>? = null

    private var provisioningState: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value The destination CIDR to which the route applies.
     */
    @JvmName("gqedsylwoqrxiiog")
    public suspend fun addressPrefix(`value`: Output<String>) {
        this.addressPrefix = value
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("ydpruygdomfvtlgo")
    public suspend fun etag(`value`: Output<String>) {
        this.etag = value
    }

    /**
     * @param value A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
     */
    @JvmName("xfbwgiahxuisgwcy")
    public suspend fun hasBgpOverride(`value`: Output<Boolean>) {
        this.hasBgpOverride = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("wuuvnwuwvqxpgodt")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("dxhdspvohhkfdrbc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
     */
    @JvmName("jutccdvaaiskoqsk")
    public suspend fun nextHopIpAddress(`value`: Output<String>) {
        this.nextHopIpAddress = value
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("rlaavbxupxhxwuxt")
    public suspend fun nextHopType(`value`: Output<Either<String, RouteNextHopType>>) {
        this.nextHopType = value
    }

    /**
     * @param value The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
     */
    @JvmName("csptvkkyeulhdgki")
    public suspend fun provisioningState(`value`: Output<String>) {
        this.provisioningState = value
    }

    /**
     * @param value The type of the resource.
     */
    @JvmName("dgspmxijeghbgnwf")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The destination CIDR to which the route applies.
     */
    @JvmName("wivtvrsihooetbmb")
    public suspend fun addressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefix = mapped
    }

    /**
     * @param value A unique read-only string that changes whenever the resource is updated.
     */
    @JvmName("svuykfpcudypsoce")
    public suspend fun etag(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.etag = mapped
    }

    /**
     * @param value A value indicating whether this route overrides overlapping BGP routes regardless of LPM.
     */
    @JvmName("vxxwvdknkmubhckv")
    public suspend fun hasBgpOverride(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hasBgpOverride = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("dchkddutfknknwsc")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("uuafcbjttgiuojrk")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The IP address packets should be forwarded to. Next hop values are only allowed in routes where the next hop type is VirtualAppliance.
     */
    @JvmName("vhnupvgevumpieem")
    public suspend fun nextHopIpAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nextHopIpAddress = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("vsfsjtihrrbfnufi")
    public suspend fun nextHopType(`value`: Either<String, RouteNextHopType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("oeiyfjcimaxmhcta")
    public fun nextHopType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RouteNextHopType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The type of Azure hop the packet should be sent to.
     */
    @JvmName("ipuhhwulfaxijnye")
    public fun nextHopType(`value`: RouteNextHopType) {
        val toBeMapped = Either.ofRight<String, RouteNextHopType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nextHopType = mapped
    }

    /**
     * @param value The provisioning state of the resource. Possible values are: 'Updating', 'Deleting', and 'Failed'.
     */
    @JvmName("cosjsnruckhhcgjf")
    public suspend fun provisioningState(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value The type of the resource.
     */
    @JvmName("yccqeggecvvemuei")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): RouteArgs = RouteArgs(
        addressPrefix = addressPrefix,
        etag = etag,
        hasBgpOverride = hasBgpOverride,
        id = id,
        name = name,
        nextHopIpAddress = nextHopIpAddress,
        nextHopType = nextHopType ?: throw PulumiNullFieldException("nextHopType"),
        provisioningState = provisioningState,
        type = type,
    )
}
